from typing import Any, Optional, List, Dict, Tuple, Callable, Union

r"""Definitions of various information kept in netnodes.

Each address in the program has a corresponding netnode: netnode(ea).
If we have no information about an address, the corresponding netnode is not created. Otherwise we will create a netnode and save information in it. All variable length information (names, comments, offset information, etc) is stored in the netnode.
Don't forget that some information is already stored in the flags (bytes.hpp)
netnode. 
    
"""

class array_parameters_t:
    @property
    def alignment(self) -> Any: ...
    @property
    def flags(self) -> Any: ...
    @property
    def lineitems(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self, _f: int = 1, _l: int = 0, _a: int = -1) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...
    def is_default(self) -> bool:
        ...

class custom_data_type_ids_fids_array:
    @property
    def bytes(self) -> Any: ...
    @property
    def data(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getitem__(self, i: size_t) -> short:
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self, data: Any) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __iter__(self) -> Any:
        r"""Helper function, to be set as __iter__ method for qvector-, or array-based classes."""
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __len__(self) -> int:
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __setitem__(self, i: size_t, v: short) -> None:
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

class custom_data_type_ids_t:
    @property
    def dtid(self) -> Any: ...
    @property
    def fids(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...
    def get_dtid(self) -> tid_t:
        ...
    def set(self, tid: tid_t) -> None:
        ...

class enum_const_t:
    @property
    def serial(self) -> Any: ...
    @property
    def tid(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

class opinfo_t:
    @property
    def cd(self) -> Any: ...
    @property
    def ec(self) -> Any: ...
    @property
    def path(self) -> Any: ...
    @property
    def ri(self) -> Any: ...
    @property
    def strtype(self) -> Any: ...
    @property
    def tid(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

class printop_t:
    @property
    def aflags(self) -> Any: ...
    @property
    def features(self) -> Any: ...
    @property
    def flags(self) -> Any: ...
    @property
    def is_ti_valid(self) -> Any: ...
    @property
    def suspop(self) -> Any: ...
    @property
    def ti(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...
    def get_ti(self) -> opinfo_t:
        ...
    def is_aflags_initialized(self) -> bool:
        ...
    def is_f64(self) -> bool:
        ...
    def is_ti_initialized(self) -> bool:
        ...
    def set_aflags_initialized(self, v: bool = True) -> None:
        ...
    def set_ti_initialized(self, v: bool = True) -> None:
        ...

class refinfo_t:
    @property
    def base(self) -> Any: ...
    @property
    def flags(self) -> Any: ...
    @property
    def target(self) -> Any: ...
    @property
    def tdelta(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...
    def init(self, args: Any) -> None:
        ...
    def is_custom(self) -> bool:
        ...
    def is_no_ones(self) -> bool:
        ...
    def is_no_zeros(self) -> bool:
        ...
    def is_pastend(self) -> bool:
        ...
    def is_rvaoff(self) -> bool:
        ...
    def is_selfref(self) -> bool:
        ...
    def is_signed(self) -> bool:
        ...
    def is_subtract(self) -> bool:
        ...
    def is_target_optional(self) -> bool:
        r"""< is_reftype_target_optional()
        
        """
        ...
    def no_base_xref(self) -> bool:
        ...
    def set_type(self, rt: reftype_t) -> None:
        ...
    def type(self) -> reftype_t:
        ...

class strpath_ids_array:
    @property
    def bytes(self) -> Any: ...
    @property
    def data(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getitem__(self, i: size_t) -> int:
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self, data: Any) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __iter__(self) -> Any:
        r"""Helper function, to be set as __iter__ method for qvector-, or array-based classes."""
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __len__(self) -> int:
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __setitem__(self, i: size_t, v: int) -> None:
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

class strpath_t:
    @property
    def delta(self) -> Any: ...
    @property
    def ids(self) -> Any: ...
    @property
    def len(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

class switch_info_t:
    SWITCH_INFO_VERSION: int  # 2
    @property
    def custom(self) -> Any: ...
    @property
    def defjump(self) -> Any: ...
    @property
    def elbase(self) -> Any: ...
    @property
    def expr_ea(self) -> Any: ...
    @property
    def flags(self) -> Any: ...
    @property
    def ind_lowcase(self) -> Any: ...
    @property
    def jcases(self) -> Any: ...
    @property
    def jumps(self) -> Any: ...
    @property
    def lowcase(self) -> Any: ...
    @property
    def marks(self) -> Any: ...
    @property
    def ncases(self) -> Any: ...
    @property
    def regdtype(self) -> Any: ...
    @property
    def regnum(self) -> Any: ...
    @property
    def startea(self) -> Any: ...
    @property
    def values(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...
    def assign(self, other: switch_info_t) -> None:
        ...
    def clear(self) -> None:
        ...
    def get_jrange_vrange(self, jrange: range_t = None, vrange: range_t = None) -> bool:
        r"""get separate parts of the switch
        
        """
        ...
    def get_jtable_element_size(self) -> int:
        ...
    def get_jtable_size(self) -> int:
        ...
    def get_lowcase(self) -> int:
        ...
    def get_shift(self) -> int:
        r"""See SWI_SHIFT_MASK. possible answers: 0..3. 
                
        """
        ...
    def get_version(self) -> int:
        ...
    def get_vtable_element_size(self) -> int:
        ...
    def has_default(self) -> bool:
        ...
    def has_elbase(self) -> bool:
        ...
    def is_custom(self) -> bool:
        ...
    def is_indirect(self) -> bool:
        ...
    def is_nolowcase(self) -> bool:
        ...
    def is_sparse(self) -> bool:
        ...
    def is_subtract(self) -> bool:
        ...
    def is_user_defined(self) -> bool:
        ...
    def set_elbase(self, base: ida_idaapi.ea_t) -> None:
        ...
    def set_expr(self, r: int, dt: op_dtype_t) -> None:
        ...
    def set_jtable_element_size(self, size: int) -> None:
        ...
    def set_jtable_size(self, size: int) -> None:
        ...
    def set_shift(self, shift: int) -> None:
        r"""See SWI_SHIFT_MASK.
        
        """
        ...
    def set_vtable_element_size(self, size: int) -> None:
        ...
    def use_std_table(self) -> bool:
        ...

def add_encoding(encname: str) -> int:
    ...

def clr__bnot0(ea: ida_idaapi.ea_t) -> None:
    ...

def clr__bnot1(ea: ida_idaapi.ea_t) -> None:
    ...

def clr__invsign0(ea: ida_idaapi.ea_t) -> None:
    ...

def clr__invsign1(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_abits(ea: ida_idaapi.ea_t, bits: aflags_t) -> None:
    ...

def clr_align_flow(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_colored_item(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_fixed_spd(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_has_lname(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_has_ti(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_has_ti0(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_has_ti1(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_libitem(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_lzero0(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_lzero1(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_noret(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_notcode(ea: ida_idaapi.ea_t) -> None:
    r"""Clear not-code mark.
    
    """
    ...

def clr_notproc(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_retfp(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_terse_struc(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_tilcmt(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_usemodsp(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_usersp(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_userti(ea: ida_idaapi.ea_t) -> None:
    ...

def clr_zstroff(ea: ida_idaapi.ea_t) -> None:
    ...

def dbg_get_input_path() -> str:
    r"""Get debugger input file name/path (see LFLG_DBG_NOPATH)
    
    """
    ...

def del_absbase(ea: ida_idaapi.ea_t) -> None:
    ...

def del_aflags(ea: ida_idaapi.ea_t) -> None:
    ...

def del_alignment(ea: ida_idaapi.ea_t) -> None:
    ...

def del_array_parameters(ea: ida_idaapi.ea_t) -> None:
    ...

def del_custom_data_type_ids(ea: ida_idaapi.ea_t) -> None:
    ...

def del_encoding(idx: int) -> bool:
    ...

def del_ind_purged(ea: ida_idaapi.ea_t) -> None:
    ...

def del_item_color(ea: ida_idaapi.ea_t) -> bool:
    ...

def del_op_tinfo(ea: ida_idaapi.ea_t, n: int) -> None:
    ...

def del_refinfo(ea: ida_idaapi.ea_t, n: int) -> bool:
    ...

def del_source_linnum(ea: ida_idaapi.ea_t) -> None:
    ...

def del_str_type(ea: ida_idaapi.ea_t) -> None:
    ...

def del_switch_info(ea: ida_idaapi.ea_t) -> None:
    ...

def del_switch_parent(ea: ida_idaapi.ea_t) -> None:
    ...

def del_tinfo(ea: ida_idaapi.ea_t) -> None:
    ...

def delete_imports() -> None:
    ...

def ea2node(ea: ida_idaapi.ea_t) -> nodeidx_t:
    r"""Get netnode for the specified address.
    
    """
    ...

def encoding_from_strtype(strtype: int) -> str:
    ...

def end_ea2node(ea: ida_idaapi.ea_t) -> nodeidx_t:
    ...

def enum_import_names(mod_index: Any, callback: Any) -> Any:
    r"""Enumerate imports from a specific module.
    Please refer to list_imports.py example.
    
    :param mod_index: The module index
    :param callback: A callable object that will be invoked with an ea, name (could be None) and ordinal.
    :returns: 1-finished ok, -1 on error, otherwise callback return value (<=0)
    """
    ...

def find_custom_refinfo(name: str) -> int:
    r"""Get id of a custom refinfo type.
    
    """
    ...

def get_abi_name() -> Any:
    ...

def get_absbase(ea: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    ...

def get_aflags(ea: ida_idaapi.ea_t) -> aflags_t:
    ...

def get_alignment(ea: ida_idaapi.ea_t) -> int:
    ...

def get_archive_path() -> str:
    r"""Get archive file path from which input file was extracted.
    
    """
    ...

def get_array_parameters(out: array_parameters_t, ea: ida_idaapi.ea_t) -> ssize_t:
    ...

def get_asm_inc_file() -> str:
    r"""Get name of the include file.
    
    """
    ...

def get_custom_data_type_ids(cdis: custom_data_type_ids_t, ea: ida_idaapi.ea_t) -> int:
    ...

def get_custom_refinfo(crid: int) -> custom_refinfo_handler_t:
    r"""Get definition of a registered custom refinfo type.
    
    """
    ...

def get_default_encoding_idx(bpu: int) -> int:
    ...

def get_elapsed_secs() -> int:
    r"""Get seconds database stayed open.
    
    """
    ...

def get_encoding_bpu(idx: int) -> int:
    ...

def get_encoding_bpu_by_name(encname: str) -> int:
    ...

def get_encoding_name(idx: int) -> str:
    ...

def get_encoding_qty() -> int:
    ...

def get_gotea() -> ida_idaapi.ea_t:
    ...

def get_ida_notepad_text() -> str:
    r"""Get notepad text.
    
    """
    ...

def get_idb_ctime() -> time_t:
    r"""Get database creation timestamp.
    
    """
    ...

def get_idb_nopens() -> int:
    r"""Get number of times the database is opened.
    
    """
    ...

def get_ids_modnode() -> netnode:
    r"""Get ids modnode.
    
    """
    ...

def get_imagebase() -> ida_idaapi.ea_t:
    r"""Get image base address.
    
    """
    ...

def get_import_module_name(mod_index: Any) -> Any:
    r"""Returns the name of an imported module given its index
    
    :param mod_index: the module index
    :returns: None or the module name
    """
    ...

def get_import_module_qty() -> uint:
    ...

def get_ind_purged(ea: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    ...

def get_initial_ida_version() -> str:
    r"""Get version of ida which created the database (string format like "7.5")
    
    """
    ...

def get_initial_idb_version() -> ushort:
    r"""Get initial version of the database (numeric format like 700)
    
    """
    ...

def get_initial_version() -> ushort:
    r"""Get initial version of the database (numeric format like 700)
    
    """
    ...

def get_input_file_path() -> str:
    r"""Get full path of the input file.
    
    """
    ...

def get_item_color(ea: ida_idaapi.ea_t) -> bgcolor_t:
    ...

def get_loader_format_name() -> str:
    r"""Get file format name for loader modules.
    
    """
    ...

def get_op_tinfo(tif: tinfo_t, ea: ida_idaapi.ea_t, n: int) -> bool:
    ...

def get_outfile_encoding_idx() -> int:
    ...

def get_refinfo(ri: refinfo_t, ea: ida_idaapi.ea_t, n: int) -> bool:
    ...

def get_reftype_by_size(size: size_t) -> reftype_t:
    r"""Get REF_... constant from size Supported sizes: 1,2,4,8,16 For other sizes returns reftype_t(-1) 
            
    """
    ...

def get_root_filename() -> str:
    r"""Get file name only of the input file.
    
    """
    ...

def get_source_linnum(ea: ida_idaapi.ea_t) -> int:
    ...

def get_srcdbg_paths() -> str:
    r"""Get source debug paths.
    
    """
    ...

def get_srcdbg_undesired_paths() -> str:
    r"""Get user-closed source files.
    
    """
    ...

def get_str_encoding_idx(strtype: int) -> uchar:
    ...

def get_str_term1(strtype: int) -> char:
    ...

def get_str_term2(strtype: int) -> char:
    ...

def get_str_type(ea: ida_idaapi.ea_t) -> int:
    ...

def get_str_type_code(strtype: int) -> uchar:
    ...

def get_str_type_prefix_length(strtype: int) -> int:
    ...

def get_strid(ea: ida_idaapi.ea_t) -> tid_t:
    ...

def get_strtype_bpu(strtype: int) -> int:
    ...

def get_switch_info(args: Any) -> Any:
    ...

def get_switch_parent(ea: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    ...

def get_tinfo(tif: tinfo_t, ea: ida_idaapi.ea_t) -> bool:
    ...

def getnode(ea: ida_idaapi.ea_t) -> netnode:
    ...

def has_aflag_linnum(flags: aflags_t) -> bool:
    ...

def has_aflag_lname(flags: aflags_t) -> bool:
    ...

def has_aflag_ti(flags: aflags_t) -> bool:
    ...

def has_aflag_ti0(flags: aflags_t) -> bool:
    ...

def has_aflag_ti1(flags: aflags_t) -> bool:
    ...

def has_lname(ea: ida_idaapi.ea_t) -> bool:
    ...

def has_ti(ea: ida_idaapi.ea_t) -> bool:
    ...

def has_ti0(ea: ida_idaapi.ea_t) -> bool:
    ...

def has_ti1(ea: ida_idaapi.ea_t) -> bool:
    ...

def hide_border(ea: ida_idaapi.ea_t) -> None:
    ...

def hide_item(ea: ida_idaapi.ea_t) -> None:
    ...

def is__bnot0(ea: ida_idaapi.ea_t) -> bool:
    ...

def is__bnot1(ea: ida_idaapi.ea_t) -> bool:
    ...

def is__invsign0(ea: ida_idaapi.ea_t) -> bool:
    ...

def is__invsign1(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_aflag__bnot0(flags: aflags_t) -> bool:
    ...

def is_aflag__bnot1(flags: aflags_t) -> bool:
    ...

def is_aflag__invsign0(flags: aflags_t) -> bool:
    ...

def is_aflag__invsign1(flags: aflags_t) -> bool:
    ...

def is_aflag_align_flow(flags: aflags_t) -> bool:
    ...

def is_aflag_colored_item(flags: aflags_t) -> bool:
    ...

def is_aflag_data_guessed_by_hexrays(flags: aflags_t) -> bool:
    ...

def is_aflag_fixed_spd(flags: aflags_t) -> bool:
    ...

def is_aflag_func_guessed_by_hexrays(flags: aflags_t) -> bool:
    ...

def is_aflag_hidden_border(flags: aflags_t) -> bool:
    ...

def is_aflag_hidden_item(flags: aflags_t) -> bool:
    ...

def is_aflag_libitem(flags: aflags_t) -> bool:
    ...

def is_aflag_lzero0(flags: aflags_t) -> bool:
    ...

def is_aflag_lzero1(flags: aflags_t) -> bool:
    ...

def is_aflag_manual_insn(flags: aflags_t) -> bool:
    ...

def is_aflag_noret(flags: aflags_t) -> bool:
    ...

def is_aflag_notcode(flags: aflags_t) -> bool:
    ...

def is_aflag_notproc(flags: aflags_t) -> bool:
    ...

def is_aflag_public_name(flags: aflags_t) -> bool:
    ...

def is_aflag_retfp(flags: aflags_t) -> bool:
    ...

def is_aflag_terse_struc(flags: aflags_t) -> bool:
    ...

def is_aflag_tilcmt(flags: aflags_t) -> bool:
    ...

def is_aflag_type_determined_by_hexrays(flags: aflags_t) -> bool:
    ...

def is_aflag_type_guessed_by_hexrays(flags: aflags_t) -> bool:
    ...

def is_aflag_type_guessed_by_ida(flags: aflags_t) -> bool:
    ...

def is_aflag_usersp(flags: aflags_t) -> bool:
    ...

def is_aflag_userti(flags: aflags_t) -> bool:
    ...

def is_aflag_weak_name(flags: aflags_t) -> bool:
    ...

def is_aflag_zstroff(flags: aflags_t) -> bool:
    ...

def is_align_flow(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_colored_item(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_data_guessed_by_hexrays(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_finally_visible_item(ea: ida_idaapi.ea_t) -> bool:
    r"""Is instruction visible?
    
    """
    ...

def is_fixed_spd(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_func_guessed_by_hexrays(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_hidden_border(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_hidden_item(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_libitem(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_lzero0(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_lzero1(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_noret(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_notcode(ea: ida_idaapi.ea_t) -> bool:
    r"""Is the address marked as not-code?
    
    """
    ...

def is_notproc(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_pascal(strtype: int) -> bool:
    ...

def is_reftype_target_optional(type: reftype_t) -> bool:
    r"""Can the target be calculated using operand value?
    
    """
    ...

def is_retfp(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_terse_struc(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_tilcmt(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_type_determined_by_hexrays(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_type_guessed_by_hexrays(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_type_guessed_by_ida(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_usersp(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_userti(ea: ida_idaapi.ea_t) -> bool:
    ...

def is_visible_item(ea: ida_idaapi.ea_t) -> bool:
    r"""Test visibility of item at given ea.
    
    """
    ...

def is_zstroff(ea: ida_idaapi.ea_t) -> bool:
    ...

def make_str_type(type_code: uchar, encoding_idx: int, term1: uchar = 0, term2: uchar = 0) -> int:
    ...

def node2ea(ndx: nodeidx_t) -> ida_idaapi.ea_t:
    ...

def rename_encoding(idx: int, encname: str) -> bool:
    ...

def retrieve_input_file_crc32() -> int:
    r"""Get input file crc32 stored in the database. it can be used to check that the input file has not been changed. 
            
    """
    ...

def retrieve_input_file_md5() -> bytes:
    r"""Get input file md5.
    
    """
    ...

def retrieve_input_file_sha256() -> bytes:
    r"""Get input file sha256.
    
    """
    ...

def retrieve_input_file_size() -> int:
    r"""Get size of input file in bytes.
    
    """
    ...

def set__bnot0(ea: ida_idaapi.ea_t) -> None:
    ...

def set__bnot1(ea: ida_idaapi.ea_t) -> None:
    ...

def set__invsign0(ea: ida_idaapi.ea_t) -> None:
    ...

def set__invsign1(ea: ida_idaapi.ea_t) -> None:
    ...

def set_abits(ea: ida_idaapi.ea_t, bits: aflags_t) -> None:
    ...

def set_absbase(ea: ida_idaapi.ea_t, x: ida_idaapi.ea_t) -> None:
    ...

def set_aflags(ea: ida_idaapi.ea_t, flags: aflags_t) -> None:
    ...

def set_align_flow(ea: ida_idaapi.ea_t) -> None:
    ...

def set_alignment(ea: ida_idaapi.ea_t, x: int) -> None:
    ...

def set_archive_path(file: str) -> bool:
    r"""Set archive file path from which input file was extracted.
    
    """
    ...

def set_array_parameters(ea: ida_idaapi.ea_t, _in: array_parameters_t) -> None:
    ...

def set_asm_inc_file(file: str) -> bool:
    r"""Set name of the include file.
    
    """
    ...

def set_colored_item(ea: ida_idaapi.ea_t) -> None:
    ...

def set_custom_data_type_ids(ea: ida_idaapi.ea_t, cdis: custom_data_type_ids_t) -> None:
    ...

def set_data_guessed_by_hexrays(ea: ida_idaapi.ea_t) -> None:
    ...

def set_default_encoding_idx(bpu: int, idx: int) -> bool:
    ...

def set_fixed_spd(ea: ida_idaapi.ea_t) -> None:
    ...

def set_func_guessed_by_hexrays(ea: ida_idaapi.ea_t) -> None:
    ...

def set_gotea(gotea: ida_idaapi.ea_t) -> None:
    ...

def set_has_lname(ea: ida_idaapi.ea_t) -> None:
    ...

def set_has_ti(ea: ida_idaapi.ea_t) -> None:
    ...

def set_has_ti0(ea: ida_idaapi.ea_t) -> None:
    ...

def set_has_ti1(ea: ida_idaapi.ea_t) -> None:
    ...

def set_ida_notepad_text(text: str, size: size_t = 0) -> None:
    r"""Set notepad text.
    
    """
    ...

def set_ids_modnode(id: netnode) -> None:
    r"""Set ids modnode.
    
    """
    ...

def set_imagebase(base: ida_idaapi.ea_t) -> None:
    r"""Set image base address.
    
    """
    ...

def set_item_color(ea: ida_idaapi.ea_t, color: bgcolor_t) -> None:
    ...

def set_libitem(ea: ida_idaapi.ea_t) -> None:
    ...

def set_loader_format_name(name: str) -> None:
    r"""Set file format name for loader modules.
    
    """
    ...

def set_lzero0(ea: ida_idaapi.ea_t) -> None:
    ...

def set_lzero1(ea: ida_idaapi.ea_t) -> None:
    ...

def set_noret(ea: ida_idaapi.ea_t) -> None:
    ...

def set_notcode(ea: ida_idaapi.ea_t) -> None:
    r"""Mark address so that it cannot be converted to instruction.
    
    """
    ...

def set_notproc(ea: ida_idaapi.ea_t) -> None:
    ...

def set_op_tinfo(ea: ida_idaapi.ea_t, n: int, tif: tinfo_t) -> bool:
    ...

def set_outfile_encoding_idx(idx: int) -> bool:
    ...

def set_refinfo(args: Any) -> bool:
    ...

def set_refinfo_ex(ea: ida_idaapi.ea_t, n: int, ri: refinfo_t) -> bool:
    ...

def set_retfp(ea: ida_idaapi.ea_t) -> None:
    ...

def set_root_filename(file: str) -> None:
    r"""Set full path of the input file.
    
    """
    ...

def set_source_linnum(ea: ida_idaapi.ea_t, lnnum: int) -> None:
    ...

def set_srcdbg_paths(paths: str) -> None:
    r"""Set source debug paths.
    
    """
    ...

def set_srcdbg_undesired_paths(paths: str) -> None:
    r"""Set user-closed source files.
    
    """
    ...

def set_str_encoding_idx(strtype: int, encoding_idx: int) -> int:
    ...

def set_str_type(ea: ida_idaapi.ea_t, x: int) -> None:
    ...

def set_switch_info(ea: ida_idaapi.ea_t, _in: switch_info_t) -> None:
    ...

def set_switch_parent(ea: ida_idaapi.ea_t, x: ida_idaapi.ea_t) -> None:
    ...

def set_terse_struc(ea: ida_idaapi.ea_t) -> None:
    ...

def set_tilcmt(ea: ida_idaapi.ea_t) -> None:
    ...

def set_tinfo(ea: ida_idaapi.ea_t, tif: tinfo_t) -> bool:
    ...

def set_type_determined_by_hexrays(ea: ida_idaapi.ea_t) -> None:
    ...

def set_type_guessed_by_ida(ea: ida_idaapi.ea_t) -> None:
    ...

def set_usemodsp(ea: ida_idaapi.ea_t) -> None:
    ...

def set_usersp(ea: ida_idaapi.ea_t) -> None:
    ...

def set_userti(ea: ida_idaapi.ea_t) -> None:
    ...

def set_visible_item(ea: ida_idaapi.ea_t, visible: bool) -> None:
    r"""Change visibility of item at given ea.
    
    """
    ...

def set_zstroff(ea: ida_idaapi.ea_t) -> None:
    ...

def switch_info_t__from_ptrval__(ptrval: size_t) -> switch_info_t:
    ...

def unhide_border(ea: ida_idaapi.ea_t) -> None:
    ...

def unhide_item(ea: ida_idaapi.ea_t) -> None:
    ...

def upd_abits(ea: ida_idaapi.ea_t, clr_bits: aflags_t, set_bits: aflags_t) -> None:
    ...

def uses_aflag_modsp(flags: aflags_t) -> bool:
    ...

def uses_modsp(ea: ida_idaapi.ea_t) -> bool:
    ...

AFL_ALIGNFLOW: int  # 16777216
AFL_BNOT0: int  # 256
AFL_BNOT1: int  # 512
AFL_COLORED: int  # 262144
AFL_FIXEDSPD: int  # 8388608
AFL_HIDDEN: int  # 16
AFL_HR_DETERMINED: int  # -1073741824
AFL_HR_GUESSED_DATA: int  # -2147483648
AFL_HR_GUESSED_FUNC: int  # 1073741824
AFL_IDA_GUESSED: int  # 0
AFL_LIB: int  # 1024
AFL_LINNUM: int  # 1
AFL_LNAME: int  # 16384
AFL_LZERO0: int  # 65536
AFL_LZERO1: int  # 131072
AFL_MANUAL: int  # 32
AFL_NOBRD: int  # 64
AFL_NORET: int  # 4194304
AFL_NOTCODE: int  # 268435456
AFL_NOTPROC: int  # 536870912
AFL_PUBNAM: int  # 4
AFL_RETFP: int  # 67108864
AFL_SIGN0: int  # 1048576
AFL_SIGN1: int  # 2097152
AFL_TERSESTR: int  # 524288
AFL_TI: int  # 2048
AFL_TI0: int  # 4096
AFL_TI1: int  # 8192
AFL_TILCMT: int  # 32768
AFL_TYPE_GUESSED: int  # -1040187392
AFL_USEMODSP: int  # 134217728
AFL_USERSP: int  # 2
AFL_USERTI: int  # 33554432
AFL_WEAKNAM: int  # 8
AFL_ZSTROFF: int  # 128
AP_ALLOWDUPS: int  # 1
AP_ARRAY: int  # 8
AP_IDXBASEMASK: int  # 240
AP_IDXBIN: int  # 48
AP_IDXDEC: int  # 0
AP_IDXHEX: int  # 16
AP_IDXOCT: int  # 32
AP_INDEX: int  # 4
AP_SIGNED: int  # 2
BPU_1B: int  # 1
BPU_2B: int  # 2
BPU_4B: int  # 4
GOTEA_NODE_IDX: int  # 0
GOTEA_NODE_NAME: str  # $ got
IDB_DESKTOPS_NODE_NAME: str  # $ desktops
IDB_DESKTOPS_TAG: str  # S
MAXSTRUCPATH: int  # 32
NALT_ABSBASE: int  # 10
NALT_AFLAGS: int  # 8
NALT_ALIGN: int  # 17
NALT_COLOR: int  # 20
NALT_CREF_FROM: str  # x
NALT_CREF_TO: str  # X
NALT_DREF_FROM: str  # d
NALT_DREF_TO: str  # D
NALT_ENUM0: int  # 11
NALT_ENUM1: int  # 12
NALT_GR_LAYX: str  # p
NALT_LINNUM: int  # 9
NALT_PURGE: int  # 15
NALT_STRTYPE: int  # 16
NALT_STRUCT: int  # 3
NALT_SWITCH: int  # 1
NSUP_ARGEAS: int  # 30
NSUP_ARRAY: int  # 5
NSUP_CMT: int  # 0
NSUP_CUSTDT: int  # 28
NSUP_EX_FLAGS: int  # 37
NSUP_FOP1: int  # 2
NSUP_FOP2: int  # 3
NSUP_FOP3: int  # 7
NSUP_FOP4: int  # 18
NSUP_FOP5: int  # 19
NSUP_FOP6: int  # 20
NSUP_FOP7: int  # 31
NSUP_FOP8: int  # 32
NSUP_FRAME: int  # 1089536
NSUP_FTAILS: int  # 28672
NSUP_GROUP: int  # 32768
NSUP_GROUPS: int  # 29
NSUP_GR_INFO: str  # g
NSUP_GR_LAYT: str  # l
NSUP_JINFO: int  # 4
NSUP_LLABEL: int  # 20480
NSUP_MANUAL: int  # 8192
NSUP_OMFGRP: int  # 6
NSUP_OPTYPES: int  # 36864
NSUP_OREF0: int  # 12
NSUP_OREF1: int  # 13
NSUP_OREF2: int  # 14
NSUP_OREF3: int  # 24
NSUP_OREF4: int  # 25
NSUP_OREF5: int  # 26
NSUP_OREF6: int  # 35
NSUP_OREF7: int  # 36
NSUP_ORIGFMD: int  # 1085440
NSUP_POINTS: int  # 4096
NSUP_REF0: int  # 9
NSUP_REF1: int  # 10
NSUP_REF2: int  # 11
NSUP_REF3: int  # 21
NSUP_REF4: int  # 22
NSUP_REF5: int  # 23
NSUP_REF6: int  # 33
NSUP_REF7: int  # 34
NSUP_REGARG: int  # 24576
NSUP_REGVAR: int  # 16384
NSUP_REPCMT: int  # 1
NSUP_SEGTRANS: int  # 17
NSUP_STROFF0: int  # 15
NSUP_STROFF1: int  # 16
NSUP_SWITCH: int  # 8
NSUP_TYPEINFO: int  # 12288
NSUP_XREFPOS: int  # 27
PATCH_TAG: str  # P
POF_IS_F64: int  # 4
POF_VALID_AFLAGS: int  # 2
POF_VALID_TI: int  # 1
REFINFO_CUSTOM: int  # 64
REFINFO_NOBASE: int  # 128
REFINFO_NO_ONES: int  # 2048
REFINFO_NO_ZEROS: int  # 1024
REFINFO_PASTEND: int  # 32
REFINFO_RVAOFF: int  # 16
REFINFO_SELFREF: int  # 4096
REFINFO_SIGNEDOP: int  # 512
REFINFO_SUBTRACT: int  # 256
REFINFO_TYPE: int  # 15
REF_HIGH16: int  # 6
REF_HIGH8: int  # 5
REF_LAST: int  # 10
REF_LOW16: int  # 4
REF_LOW8: int  # 3
REF_OFF16: int  # 1
REF_OFF32: int  # 2
REF_OFF64: int  # 9
REF_OFF8: int  # 10
RIDX_ABINAME: int  # 1350
RIDX_ARCHIVE_PATH: int  # 1351
RIDX_C_MACROS: int  # 66
RIDX_DBG_BINPATHS: int  # 1328
RIDX_DUALOP_GRAPH: int  # 1300
RIDX_DUALOP_TEXT: int  # 1301
RIDX_FILE_FORMAT_NAME: int  # 1
RIDX_GROUPS: int  # 64
RIDX_H_PATH: int  # 65
RIDX_IDA_VERSION: int  # 1303
RIDX_INCLUDE: int  # 1100
RIDX_MD5: int  # 1302
RIDX_NOTEPAD: int  # 68
RIDX_PROBLEMS: int  # 1352
RIDX_SELECTORS: int  # 2
RIDX_SHA256: int  # 1349
RIDX_SMALL_IDC: int  # 1200
RIDX_SMALL_IDC_OLD: int  # 67
RIDX_SRCDBG_PATHS: int  # 1306
RIDX_SRCDBG_UNDESIRED: int  # 1353
RIDX_STR_ENCODINGS: int  # 1305
STRENC_DEFAULT: int  # 0
STRENC_NONE: int  # 255
STRLYT_MASK: int  # 252
STRLYT_PASCAL1: int  # 1
STRLYT_PASCAL2: int  # 2
STRLYT_PASCAL4: int  # 3
STRLYT_SHIFT: int  # 2
STRLYT_TERMCHR: int  # 0
STRTYPE_C: int  # 0
STRTYPE_C_16: int  # 1
STRTYPE_C_32: int  # 2
STRTYPE_LEN2: int  # 8
STRTYPE_LEN2_16: int  # 9
STRTYPE_LEN2_32: int  # 10
STRTYPE_LEN4: int  # 12
STRTYPE_LEN4_16: int  # 13
STRTYPE_LEN4_32: int  # 14
STRTYPE_PASCAL: int  # 4
STRTYPE_PASCAL_16: int  # 5
STRTYPE_PASCAL_32: int  # 6
STRTYPE_TERMCHR: int  # 0
STRWIDTH_1B: int  # 0
STRWIDTH_2B: int  # 1
STRWIDTH_4B: int  # 2
STRWIDTH_MASK: int  # 3
SWIG_PYTHON_LEGACY_BOOL: int  # 1
SWI_CUSTOM: int  # 16384
SWI_DEFRET: int  # 1048576
SWI_DEF_IN_TBL: int  # 32
SWI_ELBASE: int  # 512
SWI_HXNOLOWCASE: int  # 262144
SWI_INDIRECT: int  # 65536
SWI_J32: int  # 4
SWI_JMPINSN: int  # 4194304
SWI_JMP_INV: int  # 64
SWI_JSIZE: int  # 1024
SWI_SELFREL: int  # 2097152
SWI_SEPARATE: int  # 4096
SWI_SHIFT_MASK: int  # 384
SWI_SIGNED: int  # 8192
SWI_SPARSE: int  # 1
SWI_STDTBL: int  # 524288
SWI_SUBTRACT: int  # 131072
SWI_USER: int  # 16
SWI_V32: int  # 2
SWI_VERSION: int  # 8388608
SWI_VSIZE: int  # 2048
SWI_VSPLIT: int  # 8
V695_REF_OFF8: int  # 0
V695_REF_VHIGH: int  # 7
V695_REF_VLOW: int  # 8
annotations: _Feature  # _Feature((3, 7, 0, 'beta', 1), None, 16777216)
cvar: swigvarlink
ida_idaapi: module
weakref: module


from typing import Any, Optional, List, Dict, Tuple, Callable, Union

r"""Functions that deal with segments.

IDA requires that all program addresses belong to segments (each address must belong to exactly one segment). The situation when an address doesn't belong to any segment is allowed as a temporary situation only when the user changes program segmentation. Bytes outside a segment can't be converted to instructions, have names, comments, etc. Each segment has its start address, ending address and represents a contiguous range of addresses. There might be unused holes between segments.
Each segment has its unique segment selector. This selector is used to distinguish the segment from other segments. For 16-bit programs the selector is equal to the segment base paragraph. For 32-bit programs there is special array to translate the selectors to the segment base paragraphs. A selector is a 32/64 bit value.
The segment base paragraph determines the offsets in the segment. If the start address of the segment == (base << 4) then the first offset in the segment will be 0. The start address should be higher or equal to (base << 4). We will call the offsets in the segment 'virtual addresses'. So, the virtual address of the first byte of the segment is
(start address of segment - segment base linear address)
For IBM PC, the virtual address corresponds to the offset part of the address. For other processors (Z80, for example), virtual addresses correspond to Z80 addresses and linear addresses are used only internally. For MS Windows programs the segment base paragraph is 0 and therefore the segment virtual addresses are equal to linear addresses. 
    
"""

class lock_segment:
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self, _segm: segment_t) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

class segment_defsr_array:
    @property
    def bytes(self) -> Any: ...
    @property
    def data(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getitem__(self, i: size_t) -> int:
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self, data: Any) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __iter__(self) -> Any:
        r"""Helper function, to be set as __iter__ method for qvector-, or array-based classes."""
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __len__(self) -> int:
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __setitem__(self, i: size_t, v: int) -> None:
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

class segment_t:
    @property
    def align(self) -> Any: ...
    @property
    def bitness(self) -> Any: ...
    @property
    def color(self) -> Any: ...
    @property
    def comb(self) -> Any: ...
    @property
    def defsr(self) -> Any: ...
    @property
    def end_ea(self) -> Any: ...
    @property
    def flags(self) -> Any: ...
    @property
    def name(self) -> Any: ...
    @property
    def orgbase(self) -> Any: ...
    @property
    def perm(self) -> Any: ...
    @property
    def sclass(self) -> Any: ...
    @property
    def sel(self) -> Any: ...
    @property
    def start_ea(self) -> Any: ...
    @property
    def type(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, r: range_t) -> bool:
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, r: range_t) -> bool:
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, r: range_t) -> bool:
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, r: range_t) -> bool:
        ...
    def __lt__(self, r: range_t) -> bool:
        ...
    def __ne__(self, r: range_t) -> bool:
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...
    def abits(self) -> int:
        r"""Get number of address bits.
        
        """
        ...
    def abytes(self) -> int:
        r"""Get number of address bytes.
        
        """
        ...
    def clear(self) -> None:
        r"""Set start_ea, end_ea to 0.
        
        """
        ...
    def clr_comorg(self) -> None:
        ...
    def clr_ob_ok(self) -> None:
        ...
    def comorg(self) -> bool:
        ...
    def compare(self, r: range_t) -> int:
        ...
    def contains(self, args: Any) -> bool:
        r"""This function has the following signatures:
        
            0. contains(ea: ida_idaapi.ea_t) -> bool
            1. contains(r: const range_t &) -> bool
        
        # 0: contains(ea: ida_idaapi.ea_t) -> bool
        
        Compare two range_t instances, based on the start_ea.
        
        Is 'ea' in the address range? 
                
        
        # 1: contains(r: const range_t &) -> bool
        
        Is every ea in 'r' also in this range_t?
        
        
        """
        ...
    def empty(self) -> bool:
        r"""Is the size of the range_t <= 0?
        
        """
        ...
    def extend(self, ea: ida_idaapi.ea_t) -> None:
        r"""Ensure that the range_t includes 'ea'.
        
        """
        ...
    def intersect(self, r: range_t) -> None:
        r"""Assign the range_t to the intersection between the range_t and 'r'.
        
        """
        ...
    def is_16bit(self) -> bool:
        r"""Is a 16-bit segment?
        
        """
        ...
    def is_32bit(self) -> bool:
        r"""Is a 32-bit segment?
        
        """
        ...
    def is_64bit(self) -> bool:
        r"""Is a 64-bit segment?
        
        """
        ...
    def is_header_segm(self) -> bool:
        ...
    def is_hidden_segtype(self) -> bool:
        ...
    def is_loader_segm(self) -> bool:
        ...
    def is_visible_segm(self) -> bool:
        ...
    def ob_ok(self) -> bool:
        ...
    def overlaps(self, r: range_t) -> bool:
        r"""Is there an ea in 'r' that is also in this range_t?
        
        """
        ...
    def set_comorg(self) -> None:
        ...
    def set_debugger_segm(self, debseg: bool) -> None:
        ...
    def set_header_segm(self, on: bool) -> None:
        ...
    def set_hidden_segtype(self, hide: bool) -> None:
        ...
    def set_loader_segm(self, ldrseg: bool) -> None:
        ...
    def set_ob_ok(self) -> None:
        ...
    def set_visible_segm(self, visible: bool) -> None:
        ...
    def size(self) -> int:
        r"""Get end_ea - start_ea.
        
        """
        ...
    def update(self) -> bool:
        r"""Update segment information. You must call this function after modification of segment characteristics. Note that not all fields of segment structure may be modified directly, there are special functions to modify some fields. 
                
        :returns: success
        """
        ...
    def use64(self) -> bool:
        r"""Is a 64-bit segment?
        
        """
        ...

def add_segm(para: ida_idaapi.ea_t, start: ida_idaapi.ea_t, end: ida_idaapi.ea_t, name: str, sclass: str, flags: int = 0) -> bool:
    r"""Add a new segment, second form. Segment alignment is set to saRelByte. Segment combination is "public" or "stack" (if segment class is "STACK"). Addressing mode of segment is taken as default (16bit or 32bit). Default segment registers are set to BADSEL. If a segment already exists at the specified range of addresses, this segment will be truncated. Instructions and data in the old segment will be deleted if the new segment has another addressing mode or another segment base address. 
            
    :param para: segment base paragraph. if paragraph can't fit in 16bit, then a new selector is allocated and mapped to the paragraph.
    :param start: start address of the segment. if start==BADADDR then start <- to_ea(para,0).
    :param end: end address of the segment. end address should be higher than start address. For emulate empty segments, use SEG_NULL segment type. If the end address is lower than start address, then fail. If end==BADADDR, then a segment up to the next segment will be created (if the next segment doesn't exist, then 1 byte segment will be created). If 'end' is too high and the new segment would overlap the next segment, 'end' is adjusted properly.
    :param name: name of new segment. may be nullptr
    :param sclass: class of the segment. may be nullptr. type of the new segment is modified if class is one of predefined names:
    * "CODE" -> SEG_CODE
    * "DATA" -> SEG_DATA
    * "CONST" -> SEG_DATA
    * "STACK" -> SEG_BSS
    * "BSS" -> SEG_BSS
    * "XTRN" -> SEG_XTRN
    * "COMM" -> SEG_COMM
    * "ABS" -> SEG_ABSSYM
    :param flags: Add segment flags
    :returns: 1: ok
    :returns: 0: failed, a warning message is displayed
    """
    ...

def add_segm_ex(NONNULL_s: segment_t, name: str, sclass: str, flags: int) -> bool:
    r"""Add a new segment. If a segment already exists at the specified range of addresses, this segment will be truncated. Instructions and data in the old segment will be deleted if the new segment has another addressing mode or another segment base address. 
            
    :param name: name of new segment. may be nullptr. if specified, the segment is immediately renamed
    :param sclass: class of the segment. may be nullptr. if specified, the segment class is immediately changed
    :param flags: Add segment flags
    :returns: 1: ok
    :returns: 0: failed, a warning message is displayed
    """
    ...

def add_segment_translation(segstart: ida_idaapi.ea_t, mappedseg: ida_idaapi.ea_t) -> bool:
    r"""Add segment translation. 
            
    :param segstart: start address of the segment to add translation to
    :param mappedseg: start address of the overlayed segment
    :returns: 1: ok
    :returns: 0: too many translations or bad segstart
    """
    ...

def allocate_selector(segbase: ida_idaapi.ea_t) -> sel_t:
    r"""Allocate a selector for a segment unconditionally. You must call this function before calling add_segm_ex(). add_segm() calls this function itself, so you don't need to allocate a selector. This function will allocate a new free selector and setup its mapping using find_free_selector() and set_selector() functions. 
            
    :param segbase: a new segment base paragraph
    :returns: the allocated selector number
    """
    ...

def change_segment_status(s: segment_t, is_deb_segm: bool) -> int:
    r"""Convert a debugger segment to a regular segment and vice versa. When converting debug->regular, the memory contents will be copied to the database. 
            
    :param s: segment to modify
    :param is_deb_segm: new status of the segment
    :returns: Change segment status result codes
    """
    ...

def del_segm(ea: ida_idaapi.ea_t, flags: int) -> bool:
    r"""Delete a segment. 
            
    :param ea: any address belonging to the segment
    :param flags: Segment modification flags
    :returns: 1: ok
    :returns: 0: failed, no segment at 'ea'.
    """
    ...

def del_segment_translations(segstart: ida_idaapi.ea_t) -> None:
    r"""Delete the translation list 
            
    :param segstart: start address of the segment to delete translation list
    """
    ...

def del_selector(selector: sel_t) -> None:
    r"""Delete mapping of a selector. Be wary of deleting selectors that are being used in the program, this can make a mess in the segments. 
            
    :param selector: number of selector to remove from the translation table
    """
    ...

def find_free_selector() -> sel_t:
    r"""Find first unused selector. 
            
    :returns: a number >= 1
    """
    ...

def find_selector(base: ida_idaapi.ea_t) -> sel_t:
    r"""Find a selector that has mapping to the specified paragraph. 
            
    :param base: paragraph to search in the translation table
    :returns: selector value or base
    """
    ...

def get_defsr(s: Any, reg: Any) -> Any:
    r"""Deprecated, use instead:
    value = s.defsr[reg]
    """
    ...

def get_first_seg() -> segment_t:
    r"""Get pointer to the first segment.
    
    """
    ...

def get_group_selector(grpsel: sel_t) -> sel_t:
    r"""Get common selector for a group of segments. 
            
    :param grpsel: selector of group segment
    :returns: common selector of the group or 'grpsel' if no such group is found
    """
    ...

def get_last_seg() -> segment_t:
    r"""Get pointer to the last segment.
    
    """
    ...

def get_next_seg(ea: ida_idaapi.ea_t) -> segment_t:
    r"""Get pointer to the next segment.
    
    """
    ...

def get_prev_seg(ea: ida_idaapi.ea_t) -> segment_t:
    r"""Get pointer to the previous segment.
    
    """
    ...

def get_segm_base(s: segment_t) -> ida_idaapi.ea_t:
    r"""Get segment base linear address. Segment base linear address is used to calculate virtual addresses. The virtual address of the first byte of the segment will be (start address of segment - segment base linear address) 
            
    :param s: pointer to segment
    :returns: 0 if s == nullptr, otherwise segment base linear address
    """
    ...

def get_segm_by_name(name: str) -> segment_t:
    r"""Get pointer to segment by its name. If there are several segments with the same name, returns the first of them. 
            
    :param name: segment name. may be nullptr.
    :returns: nullptr or pointer to segment structure
    """
    ...

def get_segm_by_sel(selector: sel_t) -> segment_t:
    r"""Get pointer to segment structure. This function finds a segment by its selector. If there are several segments with the same selectors, the last one will be returned. 
            
    :param selector: a segment with the specified selector will be returned
    :returns: pointer to segment or nullptr
    """
    ...

def get_segm_class(s: segment_t) -> str:
    r"""Get segment class. Segment class is arbitrary text (max 8 characters). 
            
    :param s: pointer to segment
    :returns: size of segment class (-1 if s==nullptr or bufsize<=0)
    """
    ...

def get_segm_name(s: segment_t, flags: int = 0) -> str:
    r"""Get true segment name by pointer to segment. 
            
    :param s: pointer to segment
    :param flags: 0-return name as is; 1-substitute bad symbols with _ 1 corresponds to GN_VISIBLE
    :returns: size of segment name (-1 if s==nullptr)
    """
    ...

def get_segm_num(ea: ida_idaapi.ea_t) -> int:
    r"""Get number of segment by address. 
            
    :param ea: linear address belonging to the segment
    :returns: -1 if no segment occupies the specified address. otherwise returns number of the specified segment (0..get_segm_qty()-1)
    """
    ...

def get_segm_para(s: segment_t) -> ida_idaapi.ea_t:
    r"""Get segment base paragraph. Segment base paragraph may be converted to segment base linear address using to_ea() function. In fact, to_ea(get_segm_para(s), 0) == get_segm_base(s). 
            
    :param s: pointer to segment
    :returns: 0 if s == nullptr, the segment base paragraph
    """
    ...

def get_segm_qty() -> int:
    r"""Get number of segments.
    
    """
    ...

def get_segment_alignment(align: uchar) -> str:
    r"""Get text representation of segment alignment code. 
            
    :returns: text digestable by IBM PC assembler.
    """
    ...

def get_segment_cmt(s: segment_t, repeatable: bool) -> str:
    r"""Get segment comment. 
            
    :param s: pointer to segment structure
    :param repeatable: 0: get regular comment. 1: get repeatable comment.
    :returns: size of comment or -1
    """
    ...

def get_segment_combination(comb: uchar) -> str:
    r"""Get text representation of segment combination code. 
            
    :returns: text digestable by IBM PC assembler.
    """
    ...

def get_segment_translations(transmap: eavec_t, segstart: ida_idaapi.ea_t) -> ssize_t:
    r"""Get segment translation list. 
            
    :param transmap: vector of segment start addresses for the translation list
    :param segstart: start address of the segment to get information about
    :returns: -1 if no translation list or bad segstart. otherwise returns size of translation list.
    """
    ...

def get_selector_qty() -> int:
    r"""Get number of defined selectors.
    
    """
    ...

def get_visible_segm_name(s: segment_t) -> str:
    r"""Get segment name by pointer to segment. 
            
    :param s: pointer to segment
    :returns: size of segment name (-1 if s==nullptr)
    """
    ...

def getn_selector(n: int) -> Any:
    r"""Get description of selector (0..get_selector_qty()-1)
    
    """
    ...

def getnseg(n: int) -> segment_t:
    r"""Get pointer to segment by its number. 
            
    :param n: segment number in the range (0..get_segm_qty()-1)
    :returns: nullptr or pointer to segment structure
    """
    ...

def getseg(ea: ida_idaapi.ea_t) -> segment_t:
    r"""Get pointer to segment by linear address. 
            
    :param ea: linear address belonging to the segment
    :returns: nullptr or pointer to segment structure
    """
    ...

def is_finally_visible_segm(s: segment_t) -> bool:
    r"""See SFL_HIDDEN, SCF_SHHID_SEGM.
    
    """
    ...

def is_miniidb() -> bool:
    r"""Is the database a miniidb created by the debugger?. 
            
    :returns: true if the database contains no segments or only debugger segments
    """
    ...

def is_segm_locked(segm: segment_t) -> bool:
    r"""Is a segment pointer locked?
    
    """
    ...

def is_spec_ea(ea: ida_idaapi.ea_t) -> bool:
    r"""Does the address belong to a segment with a special type?. (SEG_XTRN, SEG_GRP, SEG_ABSSYM, SEG_COMM) 
            
    :param ea: linear address
    """
    ...

def is_spec_segm(seg_type: uchar) -> bool:
    r"""Has segment a special type?. (SEG_XTRN, SEG_GRP, SEG_ABSSYM, SEG_COMM) 
            
    """
    ...

def is_visible_segm(s: segment_t) -> bool:
    r"""See SFL_HIDDEN.
    
    """
    ...

def lock_segm(segm: segment_t, lock: bool) -> None:
    r"""Lock segment pointer Locked pointers are guaranteed to remain valid until they are unlocked. Ranges with locked pointers cannot be deleted or moved. 
            
    """
    ...

def move_segm(s: segment_t, to: ida_idaapi.ea_t, flags: int = 0) -> move_segm_code_t:
    r"""This function moves all information to the new address. It fixes up address sensitive information in the kernel. The total effect is equal to reloading the segment to the target address. For the file format dependent address sensitive information, loader_t::move_segm is called. Also IDB notification event idb_event::segm_moved is called. 
            
    :param s: segment to move
    :param to: new segment start address
    :param flags: Move segment flags
    :returns: Move segment result codes
    """
    ...

def move_segm_start(ea: ida_idaapi.ea_t, newstart: ida_idaapi.ea_t, mode: int) -> bool:
    r"""Move segment start. The main difference between this function and set_segm_start() is that this function may expand the previous segment while set_segm_start() never does it. So, this function allows to change bounds of two segments simultaneously. If the previous segment and the specified segment have the same addressing mode and segment base, then instructions and data are not destroyed - they simply move from one segment to another. Otherwise all instructions/data which migrate from one segment to another are destroyed. 
            
    :param ea: any address belonging to the segment
    :param newstart: new start address of the segment note that segment start address should be higher than segment base linear address.
    :param mode: policy for destroying defined items
    * 0: if it is necessary to destroy defined items, display a dialog box and ask confirmation
    * 1: if it is necessary to destroy defined items, just destroy them without asking the user
    * -1: if it is necessary to destroy defined items, don't destroy them (i.e. function will fail)
    * -2: don't destroy defined items (function will succeed)
    :returns: 1: ok
    :returns: 0: failed, a warning message is displayed
    """
    ...

def move_segm_strerror(code: move_segm_code_t) -> str:
    r"""Return string describing error MOVE_SEGM_... code.
    
    """
    ...

def rebase_program(delta: Any, flags: int) -> int:
    r"""Rebase the whole program by 'delta' bytes. 
            
    :param delta: number of bytes to move the program
    :param flags: Move segment flags it is recommended to use MSF_FIXONCE so that the loader takes care of global variables it stored in the database
    :returns: Move segment result codes
    """
    ...

def segm_adjust_diff(s: segment_t, delta: adiff_t) -> adiff_t:
    r"""Truncate and sign extend a delta depending on the segment.
    
    """
    ...

def segm_adjust_ea(s: segment_t, ea: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    r"""Truncate an address depending on the segment.
    
    """
    ...

def segtype(ea: ida_idaapi.ea_t) -> uchar:
    r"""Get segment type. 
            
    :param ea: any linear address within the segment
    :returns: Segment types, SEG_UNDF if no segment found at 'ea'
    """
    ...

def sel2ea(selector: sel_t) -> ida_idaapi.ea_t:
    r"""Get mapping of a selector as a linear address. 
            
    :param selector: number of selector to translate to linear address
    :returns: linear address the specified selector is mapped to. if there is no mapping, returns to_ea(selector,0);
    """
    ...

def sel2para(selector: sel_t) -> ida_idaapi.ea_t:
    r"""Get mapping of a selector. 
            
    :param selector: number of selector to translate
    :returns: paragraph the specified selector is mapped to. if there is no mapping, returns 'selector'.
    """
    ...

def set_defsr(s: Any, reg: Any, value: Any) -> Any:
    r"""Deprecated, use instead:
    s.defsr[reg] = value
    """
    ...

def set_group_selector(grp: sel_t, sel: sel_t) -> int:
    r"""Create a new group of segments (used OMF files). 
            
    :param grp: selector of group segment (segment type is SEG_GRP) You should create an 'empty' (1 byte) group segment It won't contain anything and will be used to redirect references to the group of segments to the common selector.
    :param sel: common selector of all segments belonging to the segment You should create all segments within the group with the same selector value.
    :returns: 1: ok
    :returns: 0: too many groups (see MAX_GROUPS)
    """
    ...

def set_segm_addressing(s: segment_t, bitness: size_t) -> bool:
    r"""Change segment addressing mode (16, 32, 64 bits). You must use this function to change segment addressing, never change the 'bitness' field directly. This function will delete all instructions, comments and names in the segment 
            
    :param s: pointer to segment
    :param bitness: new addressing mode of segment
    * 2: 64bit segment
    * 1: 32bit segment
    * 0: 16bit segment
    :returns: success
    """
    ...

def set_segm_base(s: segment_t, newbase: ida_idaapi.ea_t) -> bool:
    r"""Internal function.
    
    """
    ...

def set_segm_class(s: segment_t, sclass: str, flags: int = 0) -> int:
    r"""Set segment class. 
            
    :param s: pointer to segment (may be nullptr)
    :param sclass: segment class (may be nullptr). If segment type is SEG_NORM and segment class is one of predefined names, then segment type is changed to:
    * "CODE" -> SEG_CODE
    * "DATA" -> SEG_DATA
    * "STACK" -> SEG_BSS
    * "BSS" -> SEG_BSS
    * if "UNK" then segment type is reset to SEG_NORM.
    :param flags: Add segment flags
    :returns: 1: ok, name is good and segment is renamed
    :returns: 0: failure, name is nullptr or bad or segment is nullptr
    """
    ...

def set_segm_end(ea: ida_idaapi.ea_t, newend: ida_idaapi.ea_t, flags: int) -> bool:
    r"""Set segment end address. The next segment is shrinked to allow expansion of the specified segment. The kernel might even delete the next segment if necessary. The kernel will ask the user for a permission to destroy instructions or data going out of segment scope if such instructions exist. 
            
    :param ea: any address belonging to the segment
    :param newend: new end address of the segment
    :param flags: Segment modification flags
    :returns: 1: ok
    :returns: 0: failed, a warning message is displayed
    """
    ...

def set_segm_name(s: segment_t, name: str, flags: int = 0) -> int:
    r"""Rename segment. The new name is validated (see validate_name). A segment always has a name. If you hadn't specified a name, the kernel will assign it "seg###" name where ### is segment number. 
            
    :param s: pointer to segment (may be nullptr)
    :param name: new segment name
    :param flags: ADDSEG_IDBENC or 0
    :returns: 1: ok, name is good and segment is renamed
    :returns: 0: failure, name is bad or segment is nullptr
    """
    ...

def set_segm_start(ea: ida_idaapi.ea_t, newstart: ida_idaapi.ea_t, flags: int) -> bool:
    r"""Set segment start address. The previous segment is trimmed to allow expansion of the specified segment. The kernel might even delete the previous segment if necessary. The kernel will ask the user for a permission to destroy instructions or data going out of segment scope if such instructions exist. 
            
    :param ea: any address belonging to the segment
    :param newstart: new start address of the segment note that segment start address should be higher than segment base linear address.
    :param flags: Segment modification flags
    :returns: 1: ok
    :returns: 0: failed, a warning message is displayed
    """
    ...

def set_segment_cmt(s: segment_t, cmt: str, repeatable: bool) -> None:
    r"""Set segment comment. 
            
    :param s: pointer to segment structure
    :param cmt: comment string, may be multiline (with '
    '). maximal size is 4096 bytes. Use empty str ("") to delete comment
    :param repeatable: 0: set regular comment. 1: set repeatable comment.
    """
    ...

def set_segment_translations(segstart: ida_idaapi.ea_t, transmap: eavec_t) -> bool:
    r"""Set new translation list. 
            
    :param segstart: start address of the segment to add translation to
    :param transmap: vector of segment start addresses for the translation list. If transmap is empty, the translation list is deleted.
    :returns: 1: ok
    :returns: 0: too many translations or bad segstart
    """
    ...

def set_selector(selector: sel_t, paragraph: ida_idaapi.ea_t) -> int:
    r"""Set mapping of selector to a paragraph. You should call this function _before_ creating a segment which uses the selector, otherwise the creation of the segment will fail. 
            
    :param selector: number of selector to map
    * if selector == BADSEL, then return 0 (fail)
    * if the selector has had a mapping, old mapping is destroyed
    * if the selector number is equal to paragraph value, then the mapping is destroyed because we don't need to keep trivial mappings.
    :param paragraph: paragraph to map selector
    :returns: 1: ok
    :returns: 0: failure (bad selector or too many mappings)
    """
    ...

def set_visible_segm(s: segment_t, visible: bool) -> None:
    r"""See SFL_HIDDEN.
    
    """
    ...

def setup_selector(segbase: ida_idaapi.ea_t) -> sel_t:
    r"""Allocate a selector for a segment if necessary. You must call this function before calling add_segm_ex(). add_segm() calls this function itself, so you don't need to allocate a selector. This function will allocate a selector if 'segbase' requires more than 16 bits and the current processor is IBM PC. Otherwise it will return the segbase value. 
            
    :param segbase: a new segment base paragraph
    :returns: the allocated selector number
    """
    ...

def std_out_segm_footer(ctx: outctx_t, seg: segment_t) -> None:
    r"""Generate segment footer line as a comment line. This function may be used in IDP modules to generate segment footer if the target assembler doesn't have 'ends' directive. 
            
    """
    ...

def take_memory_snapshot(type: int) -> bool:
    r"""Take a memory snapshot of the running process. 
            
    :param type: specifies which snapshot we want (see SNAP_ Snapshot types)
    :returns: success
    """
    ...

def update_segm(s: segment_t) -> bool:
    ...

ADDSEG_FILLGAP: int  # 16
ADDSEG_IDBENC: int  # 128
ADDSEG_NOAA: int  # 64
ADDSEG_NOSREG: int  # 1
ADDSEG_NOTRUNC: int  # 4
ADDSEG_OR_DIE: int  # 2
ADDSEG_QUIET: int  # 8
ADDSEG_SPARSE: int  # 32
CSS_BREAK: int  # -4
CSS_NODBG: int  # -1
CSS_NOMEM: int  # -3
CSS_NORANGE: int  # -2
CSS_OK: int  # 0
MAX_GROUPS: int  # 8
MAX_SEGM_TRANSLATIONS: int  # 64
MOVE_SEGM_CHUNK: int  # -4
MOVE_SEGM_DEBUG: int  # -8
MOVE_SEGM_IDP: int  # -3
MOVE_SEGM_INVAL: int  # -11
MOVE_SEGM_LOADER: int  # -5
MOVE_SEGM_MAPPING: int  # -10
MOVE_SEGM_ODD: int  # -6
MOVE_SEGM_OK: int  # 0
MOVE_SEGM_ORPHAN: int  # -7
MOVE_SEGM_PARAM: int  # -1
MOVE_SEGM_ROOM: int  # -2
MOVE_SEGM_SOURCEFILES: int  # -9
MSF_FIXONCE: int  # 8
MSF_LDKEEP: int  # 4
MSF_NETNODES: int  # 128
MSF_NOFIX: int  # 2
MSF_PRIORITY: int  # 32
MSF_SILENT: int  # 1
SEGMOD_KEEP: int  # 2
SEGMOD_KEEP0: int  # 8
SEGMOD_KEEPSEL: int  # 16
SEGMOD_KILL: int  # 1
SEGMOD_NOMOVE: int  # 32
SEGMOD_SILENT: int  # 4
SEGMOD_SPARSE: int  # 64
SEGPERM_EXEC: int  # 1
SEGPERM_MAXVAL: int  # 7
SEGPERM_READ: int  # 4
SEGPERM_WRITE: int  # 2
SEG_ABSSYM: int  # 10
SEG_BSS: int  # 9
SEG_CODE: int  # 2
SEG_COMM: int  # 11
SEG_DATA: int  # 3
SEG_GRP: int  # 6
SEG_IMEM: int  # 12
SEG_IMP: int  # 4
SEG_MAX_BITNESS_CODE: int  # 2
SEG_MAX_SEGTYPE_CODE: int  # 12
SEG_NORM: int  # 0
SEG_NULL: int  # 7
SEG_UNDF: int  # 8
SEG_XTRN: int  # 1
SFL_COMORG: int  # 1
SFL_DEBUG: int  # 8
SFL_HEADER: int  # 64
SFL_HIDDEN: int  # 4
SFL_HIDETYPE: int  # 32
SFL_LOADER: int  # 16
SFL_OBOK: int  # 2
SNAP_ALL_SEG: int  # 0
SNAP_CUR_SEG: int  # 2
SNAP_LOAD_SEG: int  # 1
SREG_NUM: int  # 16
SWIG_PYTHON_LEGACY_BOOL: int  # 1
annotations: _Feature  # _Feature((3, 7, 0, 'beta', 1), None, 16777216)
ida_idaapi: module
ida_range: module
saAbs: int  # 0
saGroup: int  # 7
saRel1024Bytes: int  # 13
saRel128Bytes: int  # 11
saRel2048Bytes: int  # 14
saRel32Bytes: int  # 8
saRel4K: int  # 6
saRel512Bytes: int  # 12
saRel64Bytes: int  # 9
saRelByte: int  # 1
saRelDble: int  # 5
saRelPage: int  # 4
saRelPara: int  # 3
saRelQword: int  # 10
saRelWord: int  # 2
saRel_MAX_ALIGN_CODE: int  # 14
scCommon: int  # 6
scGroup: int  # 1
scPriv: int  # 0
scPub: int  # 2
scPub2: int  # 4
scPub3: int  # 7
scStack: int  # 5
sc_MAX_COMB_CODE: int  # 7
weakref: module


from typing import Any, Optional, List, Dict, Tuple, Callable, Union

r"""Functions that deal with fixup information.

A loader should setup fixup information using set_fixup(). 
    
"""

class fixup_data_t:
    @property
    def displacement(self) -> Any: ...
    @property
    def off(self) -> Any: ...
    @property
    def sel(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self, args: Any) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...
    def calc_size(self) -> int:
        r"""calc_fixup_size()
        
        """
        ...
    def clr_extdef(self) -> None:
        ...
    def clr_unused(self) -> None:
        ...
    def get(self, source: ida_idaapi.ea_t) -> bool:
        r"""get_fixup()
        
        """
        ...
    def get_base(self) -> ida_idaapi.ea_t:
        r"""Get base of fixup. 
                
        """
        ...
    def get_desc(self, source: ida_idaapi.ea_t) -> str:
        r"""get_fixup_desc()
        
        """
        ...
    def get_flags(self) -> int:
        r"""Fixup flags Fixup flags.
        
        """
        ...
    def get_handler(self) -> fixup_handler_t:
        r"""get_fixup_handler()
        
        """
        ...
    def get_type(self) -> fixup_type_t:
        r"""Fixup type Types of fixups.
        
        """
        ...
    def get_value(self, ea: ida_idaapi.ea_t) -> int:
        r"""get_fixup_value()
        
        """
        ...
    def has_base(self) -> bool:
        r"""Is fixup relative?
        
        """
        ...
    def is_custom(self) -> bool:
        r"""is_fixup_custom()
        
        """
        ...
    def is_extdef(self) -> bool:
        ...
    def is_unused(self) -> bool:
        ...
    def patch_value(self, ea: ida_idaapi.ea_t) -> bool:
        r"""patch_fixup_value()
        
        """
        ...
    def set(self, source: ida_idaapi.ea_t) -> None:
        r"""set_fixup()
        
        """
        ...
    def set_base(self, new_base: ida_idaapi.ea_t) -> None:
        r"""Set base of fixup. The target should be set before a call of this function. 
                
        """
        ...
    def set_extdef(self) -> None:
        ...
    def set_sel(self, seg: segment_t) -> None:
        ...
    def set_target_sel(self) -> None:
        r"""Set selector of fixup to the target. The target should be set before a call of this function. 
                
        """
        ...
    def set_type(self, type_: fixup_type_t) -> None:
        ...
    def set_type_and_flags(self, type_: fixup_type_t, flags_: int = 0) -> None:
        ...
    def set_unused(self) -> None:
        ...
    def was_created(self) -> bool:
        r"""Is fixup artificial?
        
        """
        ...

class fixup_info_t:
    @property
    def ea(self) -> Any: ...
    @property
    def fd(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

def calc_fixup_size(type: fixup_type_t) -> int:
    r"""Calculate size of fixup in bytes (the number of bytes the fixup patches) 
            
    :returns: -1: means error
    """
    ...

def contains_fixups(ea: ida_idaapi.ea_t, size: asize_t) -> bool:
    r"""Does the specified address range contain any fixup information?
    
    """
    ...

def del_fixup(source: ida_idaapi.ea_t) -> None:
    r"""Delete fixup information.
    
    """
    ...

def exists_fixup(source: ida_idaapi.ea_t) -> bool:
    r"""Check that a fixup exists at the given address.
    
    """
    ...

def find_custom_fixup(name: str) -> fixup_type_t:
    ...

def gen_fix_fixups(_from: ida_idaapi.ea_t, to: ida_idaapi.ea_t, size: asize_t) -> None:
    r"""Relocate the bytes with fixup information once more (generic function). This function may be called from loader_t::move_segm() if it suits the goal. If loader_t::move_segm is not defined then this function will be called automatically when moving segments or rebasing the entire program. Special parameter values (from = BADADDR, size = 0, to = delta) are used when the function is called from rebase_program(delta). 
            
    """
    ...

def get_first_fixup_ea() -> ida_idaapi.ea_t:
    ...

def get_fixup(fd: fixup_data_t, source: ida_idaapi.ea_t) -> bool:
    r"""Get fixup information.
    
    """
    ...

def get_fixup_desc(source: ida_idaapi.ea_t, fd: fixup_data_t) -> str:
    r"""Get FIXUP description comment.
    
    """
    ...

def get_fixup_handler(type: fixup_type_t) -> fixup_handler_t:
    r"""Get handler of standard or custom fixup.
    
    """
    ...

def get_fixup_value(ea: ida_idaapi.ea_t, type: fixup_type_t) -> int:
    r"""Get the operand value. This function get fixup bytes from data or an instruction at `ea` and convert them to the operand value (maybe partially). It is opposite in meaning to the `patch_fixup_value()`. For example, FIXUP_HI8 read a byte at `ea` and shifts it left by 8 bits, or AArch64's custom fixup BRANCH26 get low 26 bits of the insn at `ea` and shifts it left by 2 bits. This function is mainly used to get a relocation addend. 
            
    :param ea: address to get fixup bytes from, the size of the fixup bytes depends on the fixup type.
    :param type: fixup type
    :returns: operand: value
    """
    ...

def get_fixups(out: fixups_t, ea: ida_idaapi.ea_t, size: asize_t) -> bool:
    ...

def get_next_fixup_ea(ea: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    ...

def get_prev_fixup_ea(ea: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    ...

def handle_fixups_in_macro(ri: refinfo_t, ea: ida_idaapi.ea_t, other: fixup_type_t, macro_reft_and_flags: int) -> bool:
    r"""Handle two fixups in a macro. We often combine two instruction that load parts of a value into one macro instruction. For example: 
           ADRP  X0, #var@PAGE
               ADD   X0, X0, #var@PAGEOFF  --> ADRL X0, var
          lui   $v0, %hi(var)
               addiu $v0, $v0, %lo(var)    --> la   $v0, var
    
    
            
    :returns: success ('false' means that RI was not changed)
    """
    ...

def is_fixup_custom(type: fixup_type_t) -> bool:
    r"""Is fixup processed by processor module?
    
    """
    ...

def patch_fixup_value(ea: ida_idaapi.ea_t, fd: fixup_data_t) -> bool:
    r"""Patch the fixup bytes. This function updates data or an instruction at `ea` to the fixup bytes. For example, FIXUP_HI8 updates a byte at `ea` to the high byte of `fd->off`, or AArch64's custom fixup BRANCH26 updates low 26 bits of the insn at `ea` to the value of `fd->off` shifted right by 2. 
            
    :param ea: address where data are changed, the size of the changed data depends on the fixup type.
    :param fd: fixup data
    :returns: false: the fixup bytes do not fit (e.g. `fd->off` is greater than 0xFFFFFFC for BRANCH26). The database is changed even in this case.
    """
    ...

def set_fixup(source: ida_idaapi.ea_t, fd: fixup_data_t) -> None:
    r"""Set fixup information. You should fill fixup_data_t and call this function and the kernel will remember information in the database. 
            
    :param source: the fixup source address, i.e. the address modified by the fixup
    :param fd: fixup data
    """
    ...

FIXUPF_CREATED: int  # 8
FIXUPF_EXTDEF: int  # 2
FIXUPF_LOADER_MASK: int  # -268435456
FIXUPF_REL: int  # 1
FIXUPF_UNUSED: int  # 4
FIXUP_CUSTOM: int  # 32768
FIXUP_HI16: int  # 7
FIXUP_HI8: int  # 6
FIXUP_LOW16: int  # 9
FIXUP_LOW8: int  # 8
FIXUP_OFF16: int  # 1
FIXUP_OFF16S: int  # 15
FIXUP_OFF32: int  # 4
FIXUP_OFF32S: int  # 16
FIXUP_OFF64: int  # 12
FIXUP_OFF8: int  # 13
FIXUP_OFF8S: int  # 14
FIXUP_PTR16: int  # 3
FIXUP_PTR32: int  # 5
FIXUP_SEG16: int  # 2
SWIG_PYTHON_LEGACY_BOOL: int  # 1
V695_FIXUP_VHIGH: int  # 10
V695_FIXUP_VLOW: int  # 11
annotations: _Feature  # _Feature((3, 7, 0, 'beta', 1), None, 16777216)
ida_idaapi: module
weakref: module


from typing import Any, Optional, List, Dict, Tuple, Callable, Union

r"""Functions that deal with the list of problems.

There are several problem lists. An address may be inserted to any list. The kernel simply maintains these lists, no additional processing is done.
The problem lists are accessible for the user from the View->Subviews->Problems menu item.
Addresses in the lists are kept sorted. In general IDA just maintains these lists without using them during analysis (except PR_ROLLED). 
    
"""

def forget_problem(type: problist_id_t, ea: ida_idaapi.ea_t) -> bool:
    r"""Remove an address from a problem list 
            
    :param type: problem list type
    :param ea: linear address
    :returns: success
    """
    ...

def get_problem(type: problist_id_t, lowea: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    r"""Get an address from the specified problem list. The address is not removed from the list. 
            
    :param type: problem list type
    :param lowea: the returned address will be higher or equal than the specified address
    :returns: linear address or BADADDR
    """
    ...

def get_problem_desc(t: problist_id_t, ea: ida_idaapi.ea_t) -> str:
    r"""Get the human-friendly description of the problem, if one was provided to remember_problem. 
            
    :param t: problem list type.
    :param ea: linear address.
    :returns: the message length or -1 if none
    """
    ...

def get_problem_name(type: problist_id_t, longname: bool = True) -> str:
    r"""Get problem list description.
    
    """
    ...

def is_problem_present(t: problist_id_t, ea: ida_idaapi.ea_t) -> bool:
    r"""Check if the specified address is present in the problem list.
    
    """
    ...

def remember_problem(type: problist_id_t, ea: ida_idaapi.ea_t, msg: str = None) -> None:
    r"""Insert an address to a list of problems. Display a message saying about the problem (except of PR_ATTN,PR_FINAL) PR_JUMP is temporarily ignored. 
            
    :param type: problem list type
    :param ea: linear address
    :param msg: a user-friendly message to be displayed instead of the default more generic one associated with the type of problem. Defaults to nullptr.
    """
    ...

def was_ida_decision(ea: ida_idaapi.ea_t) -> bool:
    ...

PR_ATTN: int  # 12
PR_BADSTACK: int  # 11
PR_COLLISION: int  # 15
PR_DECIMP: int  # 16
PR_DISASM: int  # 7
PR_END: int  # 17
PR_FINAL: int  # 13
PR_HEAD: int  # 8
PR_ILLADDR: int  # 9
PR_JUMP: int  # 6
PR_MANYLINES: int  # 10
PR_NOBASE: int  # 1
PR_NOCMT: int  # 4
PR_NOFOP: int  # 3
PR_NONAME: int  # 2
PR_NOXREFS: int  # 5
PR_ROLLED: int  # 14
SWIG_PYTHON_LEGACY_BOOL: int  # 1
annotations: _Feature  # _Feature((3, 7, 0, 'beta', 1), None, 16777216)
cvar: swigvarlink
ida_idaapi: module
weakref: module


from typing import Any, Optional, List, Dict, Tuple, Callable, Union

r"""
idautils.py - High level utility functions for IDA

"""

class Strings:
    r"""
    Allows iterating over the string list. The set of strings will not be
    modified, unless asked explicitly at setup()-time. This string list also
    is used by the "String window" so it may be changed when this window is
    updated.
    
    Example:
        s = Strings()
    
        for i in s:
            print("%x: len=%d type=%d -> '%s'" % (i.ea, i.length, i.strtype, str(i)))
    
    
    """
    def StringItem(self, si: Any) -> Any:
        r"""
        Class representing each string item.
        
        """
        ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getitem__(self, index: Any) -> Any:
        r"""Returns a string item or None"""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self, default_setup: Any = False) -> Any:
        r"""
        Initializes the Strings enumeration helper class
        
        :param default_setup: Set to True to use default setup (C strings, min len 5, ...)
        
        """
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __iter__(self) -> Any:
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        r"""Return repr(self)."""
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def clear_cache(self) -> Any:
        r"""Clears the string list cache"""
        ...
    def refresh(self) -> Any:
        r"""Refreshes the string list"""
        ...
    def setup(self, strtypes: Any = ..., minlen: Any = 5, only_7bit: Any = True, ignore_instructions: Any = False, display_only_existing_strings: Any = False) -> Any:
        ...

class peutils_t:
    r"""
    PE utility class. Retrieves PE information from the database.
    
    Constants from pe.h
    
    """
    PE_ALT_DBG_FPOS: int  # 18446744073709551615
    PE_ALT_IMAGEBASE: int  # 18446744073709551614
    PE_ALT_NEFLAGS: int  # 18446744073709551612
    PE_ALT_PEHDR_OFF: int  # 18446744073709551613
    PE_ALT_PSXDLL: int  # 18446744073709551610
    PE_ALT_TDS_LOADED: int  # 18446744073709551611
    PE_NODE: str  # $ PE header
    @property
    def header_offset(self) -> Any: ...
    @property
    def imagebase(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def header(self) -> Any:
        ...

def Assemble(ea: Any, line: Any) -> Any:
    r"""
    Assembles one or more lines (does not display an message dialogs)
    If line is a list then this function will attempt to assemble all the lines
    This function will turn on batch mode temporarily so that no messages are displayed on the screen
    
    :param ea:       start address
    :returns: (False, "Error message") or (True, asm_buf) or (True, [asm_buf1, asm_buf2, asm_buf3])
    
    """
    ...

def Chunks(start: Any) -> Any:
    r"""
    Get a list of function chunks
    See also ida_funcs.func_tail_iterator_t
    
    :param start: address of the function
    
    :returns: list of function chunks (tuples of the form (start_ea, end_ea))
             belonging to the function
    
    """
    ...

def CodeRefsFrom(ea: Any, flow: bool) -> Any:
    r"""
    Get a list of code references from 'ea'
    
    :param ea:   Target address
    :param flow: Follow normal code flow or not
    
    :returns: list of references (may be empty list)
    
    Example::
    
        for ref in CodeRefsFrom(get_screen_ea(), 1):
            print(ref)
    
    """
    ...

def CodeRefsTo(ea: Any, flow: bool) -> Any:
    r"""
    Get a list of code references to 'ea'
    
    :param ea:   Target address
    :param flow: Follow normal code flow or not
    
    :returns: list of references (may be empty list)
    
    Example::
    
        for ref in CodeRefsTo(get_screen_ea(), 1):
            print(ref)
    
    """
    ...

def DataRefsFrom(ea: Any) -> Any:
    r"""
    Get a list of data references from 'ea'
    
    :param ea:   Target address
    
    :returns: list of references (may be empty list)
    
    Example::
    
        for ref in DataRefsFrom(get_screen_ea()):
            print(ref)
    
    """
    ...

def DataRefsTo(ea: Any) -> Any:
    r"""
    Get a list of data references to 'ea'
    
    :param ea:   Target address
    
    :returns: list of references (may be empty list)
    
    Example::
    
        for ref in DataRefsTo(get_screen_ea()):
            print(ref)
    
    """
    ...

def DecodeInstruction(ea: Any) -> Any:
    r"""
    Decodes an instruction and returns an insn_t like class
    
    :param ea: address to decode
    :returns: None or a new insn_t instance
    
    """
    ...

def DecodePrecedingInstruction(ea: Any) -> Any:
    r"""
    Decode preceding instruction in the execution flow.
    
    :param ea: address to decode
    :returns: (None or the decode instruction, farref)
             farref will contain 'true' if followed an xref, false otherwise
    
    """
    ...

def DecodePreviousInstruction(ea: Any) -> Any:
    r"""
    Decodes the previous instruction and returns an insn_t like class
    
    :param ea: address to decode
    :returns: None or a new insn_t instance
    
    """
    ...

def Entries() -> Any:
    r"""
    Returns a list of entry points (exports)
    
    :returns: List of tuples (index, ordinal, ea, name)
    
    """
    ...

def FuncItems(start: Any) -> Any:
    r"""
    Get a list of function items (instruction or data items inside function boundaries)
    See also ida_funcs.func_item_iterator_t
    
    :param start: address of the function
    
    :returns: ea of each item in the function
    
    """
    ...

def Functions(start: Any = None, end: Any = None) -> Any:
    r"""
    Get a list of functions
    
    :param start: start address (default: inf.min_ea)
    :param end:   end address (default: inf.max_ea)
    
    :returns: list of function entrypoints between start and end
    
    NOTE: The last function that starts before 'end' is included even
    if it extends beyond 'end'. Any function that has its chunks scattered
    in multiple segments will be reported multiple times, once in each segment
    as they are listed.
    
    """
    ...

def GetDataList(ea: Any, count: Any, itemsize: Any = 1) -> Any:
    r"""
    Get data list - INTERNAL USE ONLY
    
    """
    ...

def GetIdbDir() -> Any:
    r"""
    Get IDB directory
    
    This function returns directory path of the current IDB database
    
    """
    ...

def GetInputFileMD5() -> bytes:
    r"""Get input file md5.
    
    """
    ...

def GetInstructionList() -> Any:
    r"""Returns the instruction list of the current processor module"""
    ...

def GetRegisterList() -> Any:
    r"""Returns the register list"""
    ...

def Heads(start: Any = None, end: Any = None) -> Any:
    r"""
    Get a list of heads (instructions or data items)
    
    :param start: start address (default: inf.min_ea)
    :param end:   end address (default: inf.max_ea)
    
    :returns: list of heads between start and end
    
    """
    ...

def MapDataList(ea: Any, length: Any, func: Any, wordsize: Any = 1) -> Any:
    r"""
    Map through a list of data words in the database
    
    :param ea:       start address
    :param length:   number of words to map
    :param func:     mapping function
    :param wordsize: size of words to map [default: 1 byte]
    
    :returns: None
    
    """
    ...

def Modules() -> Any:
    r"""
    Returns a list of module objects with name,size,base and the rebase_to attributes
    
    """
    ...

def Names() -> Any:
    r"""
    Returns a list of names
    
    :returns: List of tuples (ea, name)
    
    """
    ...

def ProcessUiActions(actions: Any, flags: Any = 0) -> Any:
    r"""
    :param actions: A string containing a list of actions separated by semicolon, a list or a tuple
    :param flags: flags to be passed to process_ui_action()
    :returns: Boolean. Returns False if the action list was empty or execute_ui_requests() failed.
    
    """
    ...

def PutDataList(ea: Any, datalist: Any, itemsize: Any = 1) -> Any:
    r"""
    Put data list - INTERNAL USE ONLY
    
    """
    ...

def Segments() -> Any:
    r"""
    Get list of segments (sections) in the binary image
    
    :returns: List of segment start addresses.
    
    """
    ...

def StructMembers(sid: Any) -> Any:
    r"""
    Get a list of structure members information (or stack vars if given a frame).
    
    :param sid: ID of the structure.
    
    :returns: List of tuples (offset_in_bytes, name, size_in_bytes)
    
    NOTE: If 'sid' does not refer to a valid structure, an exception will be raised.
    NOTE: This will not return 'holes' in structures/stack frames; it only returns defined structure members.
    
    """
    ...

def Structs() -> Any:
    r"""
    Get a list of structures
    
    :returns: List of tuples (ordinal, sid, name)
    
    """
    ...

def Threads() -> Any:
    r"""Returns all thread IDs for the current debugee"""
    ...

def XrefTypeName(typecode: Any) -> Any:
    r"""
    Convert cross-reference type codes to readable names
    
    :param typecode: cross-reference type code
    
    """
    ...

def XrefsFrom(ea: Any, flags: Any = 0) -> Any:
    r"""
    Return all references from address 'ea'
    
    :param ea: Reference address
    :param flags: one of ida_xref.XREF_ALL (default), ida_xref.XREF_FAR, ida_xref.XREF_DATA
    
    Example::
           for xref in XrefsFrom(here(), 0):
               print(xref.type, XrefTypeName(xref.type),                          'from', hex(xref.frm), 'to', hex(xref.to))
    
    """
    ...

def XrefsTo(ea: Any, flags: Any = 0) -> Any:
    r"""
    Return all references to address 'ea'
    
    :param ea: Reference address
    :param flags: one of ida_xref.XREF_ALL (default), ida_xref.XREF_FAR, ida_xref.XREF_DATA
    
    Example::
           for xref in XrefsTo(here(), 0):
               print(xref.type, XrefTypeName(xref.type),                          'from', hex(xref.frm), 'to', hex(xref.to))
    
    """
    ...

cpu: _cpu  # <idautils._cpu object at 0x7acfb4292900>
ida_bytes: module
ida_dbg: module
ida_entry: module
ida_funcs: module
ida_ida: _module_wrapper_t
ida_idaapi: module
ida_idd: module
ida_idp: module
ida_kernwin: module
ida_loader: module
ida_nalt: module
ida_name: module
ida_netnode: module
ida_segment: module
ida_strlist: module
ida_typeinf: module
ida_ua: module
ida_xref: module
idc: _module_wrapper_t
os: module  # <module 'os' (frozen)>
procregs: _procregs  # <idautils._procregs object at 0x7acfb4293230>
sys: module  # <module 'sys' (built-in)>
types: module


from typing import Any, Optional, List, Dict, Tuple, Callable, Union

r"""Functions that work with the autoanalyzer queue.

The autoanalyzer works when IDA is not busy processing the user keystrokes. It has several queues, each queue having its own priority. The analyzer stops when all queues are empty.
A queue contains addresses or address ranges. The addresses are kept sorted by their values. The analyzer will process all addresses from the first queue, then switch to the second queue and so on. There are no limitations on the size of the queues.
This file also contains functions that deal with the IDA status indicator and the autoanalysis indicator. You may use these functions to change the indicator value. 
    
"""

class auto_display_t:
    @property
    def ea(self) -> Any: ...
    @property
    def state(self) -> Any: ...
    @property
    def type(self) -> Any: ...
    def __delattr__(self, name: Any) -> Any:
        r"""Implement delattr(self, name)."""
        ...
    def __dir__(self) -> Any:
        r"""Default dir() implementation."""
        ...
    def __eq__(self, value: Any) -> Any:
        r"""Return self==value."""
        ...
    def __format__(self, format_spec: Any) -> Any:
        r"""Default object formatter.
        
        Return str(self) if format_spec is empty. Raise TypeError otherwise.
        """
        ...
    def __ge__(self, value: Any) -> Any:
        r"""Return self>=value."""
        ...
    def __getattribute__(self, name: Any) -> Any:
        r"""Return getattr(self, name)."""
        ...
    def __getstate__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __gt__(self, value: Any) -> Any:
        r"""Return self>value."""
        ...
    def __hash__(self) -> Any:
        r"""Return hash(self)."""
        ...
    def __init__(self) -> Any:
        ...
    def __init_subclass__(self) -> Any:
        r"""This method is called when a class is subclassed.
        
        The default implementation does nothing. It may be
        overridden to extend subclasses.
        
        """
        ...
    def __le__(self, value: Any) -> Any:
        r"""Return self<=value."""
        ...
    def __lt__(self, value: Any) -> Any:
        r"""Return self<value."""
        ...
    def __ne__(self, value: Any) -> Any:
        r"""Return self!=value."""
        ...
    def __new__(self, args: Any, kwargs: Any) -> Any:
        r"""Create and return a new object.  See help(type) for accurate signature."""
        ...
    def __reduce__(self) -> Any:
        r"""Helper for pickle."""
        ...
    def __reduce_ex__(self, protocol: Any) -> Any:
        r"""Helper for pickle."""
        ...
    def __repr__(self) -> Any:
        ...
    def __setattr__(self, name: Any, value: Any) -> Any:
        r"""Implement setattr(self, name, value)."""
        ...
    def __sizeof__(self) -> Any:
        r"""Size of object in memory, in bytes."""
        ...
    def __str__(self) -> Any:
        r"""Return str(self)."""
        ...
    def __subclasshook__(self, object: Any) -> Any:
        r"""Abstract classes can override this to customize issubclass().
        
        This is invoked early on by abc.ABCMeta.__subclasscheck__().
        It should return True, False or NotImplemented.  If it returns
        NotImplemented, the normal algorithm is used.  Otherwise, it
        overrides the normal algorithm (and the outcome is cached).
        
        """
        ...
    def __swig_destroy__(self, object: Any) -> Any:
        ...

def auto_apply_tail(tail_ea: ida_idaapi.ea_t, parent_ea: ida_idaapi.ea_t) -> None:
    r"""Plan to apply the tail_ea chunk to the parent 
            
    :param tail_ea: linear address of start of tail
    :param parent_ea: linear address within parent. If BADADDR, automatically try to find parent via xrefs.
    """
    ...

def auto_apply_type(caller: ida_idaapi.ea_t, callee: ida_idaapi.ea_t) -> None:
    r"""Plan to apply the callee's type to the calling point.
    
    """
    ...

def auto_cancel(ea1: ida_idaapi.ea_t, ea2: ida_idaapi.ea_t) -> None:
    r"""Remove an address range (ea1..ea2) from queues AU_CODE, AU_PROC, AU_USED. To remove an address range from other queues use auto_unmark() function. 'ea1' may be higher than 'ea2', the kernel will swap them in this case. 'ea2' doesn't belong to the range. 
            
    """
    ...

def auto_get(type: atype_t, lowEA: ida_idaapi.ea_t, highEA: ida_idaapi.ea_t) -> ida_idaapi.ea_t:
    r"""Retrieve an address from queues regarding their priority. Returns BADADDR if no addresses not lower than 'lowEA' and less than 'highEA' are found in the queues. Otherwise *type will have queue type. 
            
    """
    ...

def auto_is_ok() -> bool:
    r"""Are all queues empty? (i.e. has autoanalysis finished?). 
            
    """
    ...

def auto_make_code(ea: ida_idaapi.ea_t) -> None:
    r"""Plan to make code.
    
    """
    ...

def auto_make_proc(ea: ida_idaapi.ea_t) -> None:
    r"""Plan to make code&function.
    
    """
    ...

def auto_make_step(ea1: ida_idaapi.ea_t, ea2: ida_idaapi.ea_t) -> bool:
    r"""Analyze one address in the specified range and return true. 
            
    :returns: if processed anything. false means that there is nothing to process in the specified range.
    """
    ...

def auto_mark(ea: ida_idaapi.ea_t, type: atype_t) -> None:
    r"""Put single address into a queue. Queues keep addresses sorted.
    
    """
    ...

def auto_mark_range(start: ida_idaapi.ea_t, end: ida_idaapi.ea_t, type: atype_t) -> None:
    r"""Put range of addresses into a queue. 'start' may be higher than 'end', the kernel will swap them in this case. 'end' doesn't belong to the range. 
            
    """
    ...

def auto_postpone_analysis(ea: ida_idaapi.ea_t) -> bool:
    r"""Plan to reanalyze on the second pass The typical usage of this function in emu.cpp is: if ( !auto_postpone_analysis(ea) ) op_offset(ea, 0, ...); (we make an offset only on the second pass) 
            
    """
    ...

def auto_recreate_insn(ea: ida_idaapi.ea_t) -> int:
    r"""Try to create instruction 
            
    :param ea: linear address of callee
    :returns: the length of the instruction or 0
    """
    ...

def auto_unmark(start: ida_idaapi.ea_t, end: ida_idaapi.ea_t, type: atype_t) -> None:
    r"""Remove range of addresses from a queue. 'start' may be higher than 'end', the kernel will swap them in this case. 'end' doesn't belong to the range. 
            
    """
    ...

def auto_wait() -> bool:
    r"""Process everything in the queues and return true. 
            
    :returns: false if the user clicked cancel. (the wait box must be displayed by the caller if desired)
    """
    ...

def auto_wait_range(ea1: ida_idaapi.ea_t, ea2: ida_idaapi.ea_t) -> ssize_t:
    r"""Process everything in the specified range and return true. 
            
    :returns: number of autoanalysis steps made. -1 if the user clicked cancel. (the wait box must be displayed by the caller if desired)
    """
    ...

def enable_auto(enable: bool) -> bool:
    r"""Temporarily enable/disable autoanalyzer. Not user-facing, but rather because IDA sometimes need to turn AA on/off regardless of inf.s_genflags:INFFL_AUTO 
            
    :returns: old state
    """
    ...

def get_auto_display(auto_display: auto_display_t) -> bool:
    r"""Get structure which holds the autoanalysis indicator contents.
    
    """
    ...

def get_auto_state() -> atype_t:
    r"""Get current state of autoanalyzer. If auto_state == AU_NONE, IDA is currently not running the analysis (it could be temporarily interrupted to perform the user's requests, for example). 
            
    """
    ...

def is_auto_enabled() -> bool:
    r"""Get autoanalyzer state.
    
    """
    ...

def may_create_stkvars() -> bool:
    r"""Is it allowed to create stack variables automatically?. This function should be used by IDP modules before creating stack vars. 
            
    """
    ...

def may_trace_sp() -> bool:
    r"""Is it allowed to trace stack pointer automatically?. This function should be used by IDP modules before tracing sp. 
            
    """
    ...

def peek_auto_queue(low_ea: ida_idaapi.ea_t, type: atype_t) -> ida_idaapi.ea_t:
    r"""Peek into a queue 'type' for an address not lower than 'low_ea'. Do not remove address from the queue. 
            
    :returns: the address or BADADDR
    """
    ...

def plan_and_wait(ea1: ida_idaapi.ea_t, ea2: ida_idaapi.ea_t, final_pass: bool = True) -> int:
    r"""Analyze the specified range. Try to create instructions where possible. Make the final pass over the specified range if specified. This function doesn't return until the range is analyzed. 
            
    :returns: 1: ok
    :returns: 0: Ctrl-Break was pressed
    """
    ...

def plan_ea(ea: ida_idaapi.ea_t) -> None:
    r"""Plan to perform reanalysis.
    
    """
    ...

def plan_range(sEA: ida_idaapi.ea_t, eEA: ida_idaapi.ea_t) -> None:
    r"""Plan to perform reanalysis.
    
    """
    ...

def reanalyze_callers(ea: ida_idaapi.ea_t, noret: bool) -> None:
    r"""Plan to reanalyze callers of the specified address. This function will add to AU_USED queue all instructions that call (not jump to) the specified address. 
            
    :param ea: linear address of callee
    :param noret: !=0: the callee doesn't return, mark to undefine subsequent instructions in the caller. 0: do nothing.
    """
    ...

def revert_ida_decisions(ea1: ida_idaapi.ea_t, ea2: ida_idaapi.ea_t) -> None:
    r"""Delete all analysis info that IDA generated for for the given range.
    
    """
    ...

def set_auto_state(new_state: atype_t) -> atype_t:
    r"""Set current state of autoanalyzer. 
            
    :param new_state: new state of autoanalyzer
    :returns: previous state
    """
    ...

def set_ida_state(st: idastate_t) -> idastate_t:
    r"""Change IDA status indicator value 
            
    :param st: - new indicator status
    :returns: old indicator status
    """
    ...

def show_addr(ea: ida_idaapi.ea_t) -> None:
    r"""Show an address on the autoanalysis indicator. The address is displayed in the form " @:12345678". 
            
    :param ea: - linear address to display
    """
    ...

def show_auto(args: Any) -> None:
    r"""Change autoanalysis indicator value. 
            
    :param ea: linear address being analyzed
    :param type: autoanalysis type (see Autoanalysis queues)
    """
    ...

AU_CHLB: int  # 90
AU_CODE: int  # 20
AU_FCHUNK: int  # 38
AU_FINAL: int  # 200
AU_LBF2: int  # 70
AU_LBF3: int  # 80
AU_LIBF: int  # 60
AU_NONE: int  # 0
AU_PROC: int  # 30
AU_TAIL: int  # 35
AU_TYPE: int  # 50
AU_UNK: int  # 10
AU_USD2: int  # 45
AU_USED: int  # 40
AU_WEAK: int  # 25
SWIG_PYTHON_LEGACY_BOOL: int  # 1
annotations: _Feature  # _Feature((3, 7, 0, 'beta', 1), None, 16777216)
cvar: swigvarlink
ida_idaapi: module
st_Ready: int  # 0
st_Think: int  # 1
st_Waiting: int  # 2
st_Work: int  # 3
weakref: module